import { select, 
        json,
        csv,
        tsv, 
        geoPath,
        geoMercator,
        scaleOrdinal,
        schemeCategory10,
        zoom,
        event } from 'd3';
import { feature } from 'topojson';

const svg = select('svg');
const width = parseFloat(svg.attr('width'));
const height = +svg.attr('height');
let stateNames = [];

const projection = geoMercator()
			.clipExtent([[0,0],[width,height]])
			.center([78.9, 20.6])
			.scale(770);

const pathGenerator = geoPath()
		.projection(projection);

const g = svg.append('g');

svg.call(zoom().on('zoom', () => {
	g.attr('transform', event.transform)
}));

//https://gist.githubusercontent.com/karmadude/4527959/raw/59492893c2f13ffb909ba48253fa7fa30a640c56/in-map-major-cities.json
//https://gist.githubusercontent.com/karmadude/4527959/raw/59492893c2f13ffb909ba48253fa7fa30a640c56/in-population.json

Promise.all([json('https://gist.githubusercontent.com/karmadude/4527959/raw/59492893c2f13ffb909ba48253fa7fa30a640c56/in-map-major-cities.json'),
             json('https://gist.githubusercontent.com/karmadude/4527959/raw/59492893c2f13ffb909ba48253fa7fa30a640c56/in-population.json')
            ]).then(([majorcitiesJSON, populationJSON]) => {
	 
  const populationGroup = g.append('g')
  const majorcitiesGroup = g.append('g');
  
  const population = feature(populationJSON, populationJSON.objects['india-population-2019-734']);			
  const majorcities = feature(majorcitiesJSON, majorcitiesJSON.objects.IND_adm1);
  
  const colorScale = scaleOrdinal(schemeCategory10);
  
  const populationPath = populationGroup.selectAll('path')
    .data(population.features)
  populationPath.enter().append('path')
    .attr("class", "population")
    .attr('d', d => pathGenerator(d))
  	.style('fill', d => colorScale(d.properties.st_nm))
  .append('title')
    .text(d => {
    return `${d.properties.district}, \n${d.properties.st_nm}`;
  	});
  
  const statePath = stateGroup.selectAll('path')
    .data(states.features)
  statePath.enter().append('path')
    .attr('class', 'states')
    .attr('d', d => pathGenerator(d))
});
      